@@ -45,7 +45,7 @@ has_xdg_translation (void)
 
   locale = setlocale (LC_MESSAGES, NULL);
 
-  if (strcmp (locale, "en_US") == 0 ||
+  if (strncmp (locale, "en_US", 5) == 0 ||
       strcmp (locale, "C") == 0)
     return TRUE;
   
@@ -57,7 +57,7 @@ static void
 update_locale (XdgDirEntry *old_entries)
 {
   XdgDirEntry *new_entries, *entry;
-  GtkWidget *dialog;
+  GtkWidget *dialog, *vbox;
   int exit_status;
   int fd;
   char *filename;
@@ -68,6 +68,8 @@ update_locale (XdgDirEntry *old_entries)
   GtkTreeIter iter;
   GtkWidget *treeview, *check;
   GtkCellRenderer *cell;
+  GtkWidget *scrolledwindow;
+  GtkWidget *label;
   char *std_out, *std_err;
   gboolean has_changes;
 
@@ -152,40 +154,64 @@ update_locale (XdgDirEntry *old_entries)
     }
   
   dialog = gtk_message_dialog_new (NULL, 0,
-				   GTK_MESSAGE_QUESTION,
+				   GTK_MESSAGE_WARNING,
 				   GTK_BUTTONS_NONE,
-				   _("You have logged in in a new language. Do you want to update the standard folders in your home folder to the new language?"));
+				   _("Update standard folders to current language?"));
   gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-					    _("The update would change the following folders:"));
+					    _("You have logged in in a new language. You can automatically update the names of some standard folders in your home folder to match this language. The update would change the following folders:"));
 
   gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-			  _("Keep old folders"), GTK_RESPONSE_NO,
-			  _("Update names"), GTK_RESPONSE_YES,
+			  _("_Keep Old Names"), GTK_RESPONSE_NO,
+			  _("_Update Names"), GTK_RESPONSE_YES,
 			  NULL);
 
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_NO);
+
+  vbox = gtk_vbox_new (FALSE, 6);
+  gtk_box_pack_start (GTK_BOX (GTK_MESSAGE_DIALOG (dialog)->label->parent), vbox, TRUE, TRUE, 0);
+  gtk_widget_show (vbox);
+
+  scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow),
+				  GTK_POLICY_NEVER,
+				  GTK_POLICY_NEVER);
+  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow),
+				       GTK_SHADOW_IN);  
+  
+  gtk_box_pack_start (GTK_BOX (vbox), scrolledwindow, TRUE, TRUE, 0);
   
   treeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (list_store));
 
+  gtk_tree_selection_set_mode (gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview)),
+                               GTK_SELECTION_NONE); 
+
   cell = gtk_cell_renderer_text_new ();
   gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-					       -1, _("Current folder"),
+					       -1, _("Current folder name"),
 					       cell,
 					       "text", 0,
 					       NULL);
   gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-					       -1, _("New folder"),
+					       -1, _("New folder name"),
 					       cell,
 					       "text", 1,
 					       NULL);
 
-  gtk_widget_show (treeview);
-  
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), treeview, FALSE, FALSE, 2);
+  gtk_container_add (GTK_CONTAINER (scrolledwindow),
+		     treeview);
 
-  check = gtk_check_button_new_with_label (_("Don't ask me this again"));
+  gtk_widget_show_all (scrolledwindow);
+
+  label = gtk_label_new (_("Note that existing content will not be moved."));
+  gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+  gtk_label_set_selectable (GTK_LABEL (label), TRUE);
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
+  gtk_widget_show (label);
+  gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+
+  check = gtk_check_button_new_with_mnemonic (_("_Don't ask me this again"));
+  gtk_box_pack_start (GTK_BOX (vbox), check, FALSE, FALSE, 0);
   gtk_widget_show (check);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), check, FALSE, FALSE, 2);
   
   response =  gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -245,6 +271,7 @@ int
 main (int argc, char *argv[])
 {
   XdgDirEntry *old_entries, *new_entries, *entry;
+  XdgDirEntry *desktop_entry;
   GtkBookmark *bookmark;
   GList *bookmarks, *l;
   char *old_locale;
@@ -290,10 +317,13 @@ main (int argc, char *argv[])
 	NULL};
       /* No previous bookmarks. Generate standard ones */
 
+      desktop_entry = find_dir_entry (new_entries, "DESKTOP");
       for (i = 0; make_bm_for[i] != NULL; i++)
 	{
 	  entry = find_dir_entry (new_entries, make_bm_for[i]);
-	  if (entry && strcmp (entry->path, g_get_home_dir ()) != 0)
+	  
+	  if (entry && strcmp (entry->path, g_get_home_dir ()) != 0 &&
+	      (desktop_entry == NULL || strcmp (entry->path, desktop_entry->path) != 0))
 	    {
 	      uri = g_filename_to_uri (entry->path, NULL, NULL);
 	      if (uri)
